'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; // 需要考虑三种场景
// 1. Weex环境下
// 2. weex 降级的 主客容器下
// 3. H5下 import {report} from '@ali/universal-tracker';

// import tracelog from './tracelog';
// import logger from './logger';


var _mtop = require('./mtop');

var _mtop2 = _interopRequireDefault(_mtop);

var _navigator = require('./navigator');

var _navigator2 = _interopRequireDefault(_navigator);

var _env = require('./env');

var _location = require('./location');

var _location2 = _interopRequireDefault(_location);

var _util = require('./util');

var _sso = require('./biz/sso');

var _sso2 = _interopRequireDefault(_sso);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var RAP_SUCCESS = 'RAP_SUCCESS';
var RAP_FAILURE = 'RAP_FAILURE';
var MTOP_RET_BOUND_SYMBOL = '::';
var MTOP_RET_SUCCESS = 'SUCCESS';
var MTOP_MESSAGE_NULL = 'null';
var AOP_TRUE = 'true';
var AOP_FALSE = 'false';
var rCode = /FAIL_BIZ_/;
var DISABLED_REFRESH_TOKEN = 'disabled_refreshToken';
var EXPIRED_REFRESH_TOKEN = 'expired_refreshToken';
var NOT_EXIST_AUTH_RELATION = 'not_exist_auth_relation';
var NO_ORDER = 'no_order';

/**
 *
 * @param {Object} options
 * @param {String} options.api  开放平台API Name
 * @param {String} options.version  开放平台 API Version
 * @param {Obejct} options.params   开放平台 业务参数
 * @param {String} options.namespace  开放平台 命名空间
 */
function formatOpenApiParams(options) {
  var API = 'mtop.1688.wireless.openapi.gateway';
  var data = {};

  data.namespace = options.namespace;
  data.apiName = options.api;
  data.apiVersion = '' + parseInt(options.v || options.version || '1');
  data.params = options.params;

  if (_typeof(options.params) === 'object') {
    // fix: android bug
    data.params = JSON.stringify(options.params);
  }

  var params = {
    api: API,
    type: 'POST',
    isOpenApi: true, // 约定参数 再通知Native 透传 appKey与 timestamp
    v: '1.0',
    data: data
  };

  return params;
}

/**
 * web 端 fetch 模拟
 * @param {Object} options fetch
 * @param {function} successCallback 成功回调
 * @param {function} failureCallback 错误回调
 */
function webFetch(options, successCallback, failureCallback) {
  return new Promise(function (resolve, reject) {
    fetch(options.url, options).then(function (response) {
      var headers = [];

      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = response.headers.keys()[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var key = _step.value;

          headers.push(_defineProperty({}, key, response.headers.get(key)));
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }

      return new Promise(function (resolve) {
        response.text().then(function (d) {
          resolve({
            body: d,
            header: headers
          });
        });
      });
    }).then(function (d) {
      successCallback && successCallback(d);
      resolve(d);
    }).catch(function (e) {
      failureCallback && failureCallback(e);
      reject(e);
    });
  });
}

/**
 *
 * @param {Object} options
 * @param {String} options.url   请求地址
 * @param {String} options.method 请求方式
 * @param {String} options.headers 请求头
 * @param {Object} options.body 请求体
 */
function formatHttpProxyParams(options) {
  var API = 'mtop.1688.wireless.isv.httpproxy';
  var data = {};

  data.targetUrl = options.url;
  data.method = options.method || 'GET';
  data.headers = _typeof(options.headers) === 'object' ? JSON.stringify(options.headers) : options.headers;
  data.body = options.body;

  if (_typeof(options.body) === 'object') {
    data.body = JSON.stringify(options.body);
  }

  var params = {
    api: API,
    v: '1.0',
    ecode: '1',
    data: data
  };

  return params;
}

// 这里有成功与失败的场景
// 成功-能够调通服务
// 成功-服务调用成功
// 成功-服务调用失败
// 失败
// 失败-网络异常
// 失败-网关服务异常
function formatRetJson(retJson) {
  try {
    var res = {};
    var o = {};

    retJson = (0, _util.parse2json)(retJson);

    if (RAP_SUCCESS === retJson.code) {
      res = (0, _util.parse2json)(retJson.data);

      var ret = res.ret[0].split(MTOP_RET_BOUND_SYMBOL);
      var code = ret[0].toUpperCase();

      if (MTOP_RET_SUCCESS === code) {
        o = res.data;
      } else {
        o.success = AOP_FALSE;
        o.errorCode = code.replace(rCode, '');
        o.errorMessage = ret[1] === MTOP_MESSAGE_NULL ? '' : ret[1];
      }
    } else {
      o.success = AOP_FALSE;
      o.errorCode = RAP_FAILURE;
      o.errorMessage = '接口调用异常';
    }

    return o;
  } catch (e) {
    console.error('ERROR:: ' + e);
  }
}

var before = function before(action) {
  return function (func) {
    return function () {
      action && action.apply(undefined, arguments);
      func && func.apply(undefined, arguments);
    };
  };
};

var AOP = {
  request: function request(options, successCallback, failureCallback) {
    var bizType = '3';
    var params = {};
    // 获取插件信息; 根据bizType【是否是三方】来决定使用哪个 MTOP，还是只作为MTOP通道
    if (bizType === '3') {
      params = formatOpenApiParams(options);
    } else {
      params = options;
    }
    params.data = params.data || {};

    var namespace = params.data.namespace;
    var apiName = params.data.apiName;
    var apiVersion = params.data.apiVersion;

    var start = Date.now();
    var beforeSuccess = before(function () {
      _util.logger.api('OK#' + namespace + '#' + apiName + '#' + apiVersion, params.data, Date.now() - start);
      // tracelog.traceAopApi(namespace, apiName, apiVersion, true, Date.now() - start, 'success');
    });
    var beforeFailure = before(function (data) {
      _util.logger.api('ERROR#' + namespace + '#' + apiName + '#' + apiVersion, params.data, Date.now() - start, data);
      // tracelog.traceAopApi(namespace, apiName, apiVersion, false, Date.now() - start, data.errorCode);
    });

    return _promise(params, beforeSuccess(successCallback), beforeFailure(failureCallback));
  },
  proxy: function proxy(options, successCallback, failureCallback) {
    if (_env.isWeb) {
      return webFetch(options, successCallback, failureCallback);
    }
    var params = formatHttpProxyParams(options);
    var start = Date.now();
    var beforeSuccess = before(function () {
      _util.logger.api('OK#' + params.data.targetUrl, params, Date.now() - start);
      // tracelog.traceProxyApi(params.data.targetUrl, true, Date.now() - start, 'success');
    });
    var beforeFailure = before(function (data) {
      _util.logger.api('ERROR#' + params.data.targetUrl, params, Date.now() - start, data);
      // tracelog.traceProxyApi(params.data.targetUrl, false, Date.now() - start, data.errorCode);
    });

    return _promise(params, beforeSuccess(successCallback), beforeFailure(failureCallback));
  },
  proxyV2: function proxyV2(options, successCallback, failureCallback) {
    if (_env.isWeb) {
      return webFetch(options, successCallback, failureCallback);
    }
    var params = formatHttpProxyParams(options);
    var start = Date.now();
    var beforeSuccess = before(function () {
      _util.logger.api('OK#' + params.data.targetUrl, params, Date.now() - start);
      // tracelog.traceProxyApi(params.data.targetUrl, true, Date.now() - start, 'success');
    });
    var beforeFailure = before(function (data) {
      _util.logger.api('ERROR#' + params.data.targetUrl, params, Date.now() - start, data);
      // tracelog.traceProxyApi(params.data.targetUrl, false, Date.now() - start, data.errorCode);
    });

    return _promiseV2(params, beforeSuccess(successCallback), beforeFailure(failureCallback));
  }
};

function _promise(params, successCallback, failureCallback) {
  return new Promise(function (resolve, reject) {
    _mtop2.default.request(params, function (retJson) {
      var data = formatRetJson(retJson);
      if (AOP_TRUE === String(data.success)) {
        successCallback && successCallback(data.result);
        resolve(data.result);
      } else {
        _failureCallback(data, failureCallback, reject);
      }
    }, function (retJson) {
      var data = formatRetJson(retJson);
      _failureCallback(data, failureCallback, reject);
    });
  });
};

function _promiseV2(params, successCallback, failureCallback) {
  return new Promise(function (resolve, reject) {
    _mtop2.default.requestV2(params, function (retJson) {
      var data = formatRetJson(retJson);
      if (AOP_TRUE === String(data.success)) {
        successCallback && successCallback(data.result);
        resolve(data.result);
      } else {
        _failureCallback(data, failureCallback, reject);
      }
    }, function (retJson) {
      var data = formatRetJson(retJson);
      _failureCallback(data, failureCallback, reject);
    });
  });
};

function getEmotionPageURL(options) {
  var arr = [];
  (0, _util.each)(options, function (val, key, obj) {
    if (val) {
      arr.push(key + '=' + val);
    }
  });
  var queryString = arr.join('&');
  return 'https://air.1688.com/apps/alim/open/emotion-page.html?wh_weex=true&' + queryString;
}

function _failureCallback(data, failureCallback, reject) {
  // let errorCode = data.errorCode;
  // if (errorCode === DISABLED_REFRESH_TOKEN) {
  //   let targetURL = getTargetURL('DISABLED_REFRESH_TOKEN');
  //   gotoEmotionPage(targetURL);
  //   // 是否还要reject;
  // } else if (typeof errorCode === 'undefined') {
  //   let targetURL = getTargetURL('DISABLED_TOKEN');
  //   console.error(`[aop response data]:: ${JSON.stringify(data)}, 为你跳转到: ${targetURL}`);
  //   gotoEmotionPage(targetURL);
  // } else {
  //   failureCallback && failureCallback(data);
  //   reject(data);
  // }

  var errorCode = data.errorCode;
  if (errorCode === DISABLED_REFRESH_TOKEN) {
    // token 无效
    var targetURL = getTargetURL('DISABLED_REFRESH_TOKEN');
    gotoEmotionPage(targetURL);
    // 是否还要reject;
  } else if (errorCode === EXPIRED_REFRESH_TOKEN) {
    // token 过期
    var _targetURL = getTargetURL('EXPIRED_REFRESH_TOKEN');
    gotoEmotionPage(_targetURL);
  } else if (errorCode === NOT_EXIST_AUTH_RELATION || errorCode === NO_ORDER) {
    // 用户未授权
    // gotoEmotionPage(getTargetURL('NOT_EXIST_AUTH_RELATION'));
    _sso2.default.goAuth();

    // } else if (errorCode) {
    //   // 其它错误
    //   var _targetURL2 = getTargetURL('DISABLED_TOKEN', errorCode);
    //   console.error('[aop response data]:: ' + JSON.stringify(data) + ', \u4E3A\u4F60\u8DF3\u8F6C\u5230: ' + _targetURL2);
    //   gotoEmotionPage(_targetURL2);
  } else {
    failureCallback && failureCallback(data);
    reject(data);
  }
}

function getTargetURL(errorCode) {
  var originalURL = _location2.default.href;
  var redirectURL = _location2.default.href;

  var targetURL = getEmotionPageURL({
    errorCode: errorCode,
    redirectURL: encodeURIComponent(redirectURL),
    originalURL: encodeURIComponent(originalURL)
  });

  return targetURL;
}

var isInvalidToken = false;
function gotoEmotionPage(targetURL) {
  if (!isInvalidToken) {
    _navigator2.default.push({
      url: targetURL,
      clearTop: true,
      animated: false
    }).then(function () {
      isInvalidToken = false;
    });
  }
  isInvalidToken = true;
}

exports.default = AOP;
module.exports = exports['default'];