'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _rap = require('../rap');

var _rap2 = _interopRequireDefault(_rap);

var _env = require('../env');

var _emmiter = require('./emmiter');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var eventEmitter = new _emmiter.EventEmitter();
var onPromises = {
  // page.balabala: Promise,
  // app.haha: Promise,
};

var Event = {
  on: function on(eventName, callback) {
    if (_env.isWeb) {
      eventEmitter.on(eventName, callback);
      return;
    }
    // back
    // Page.back
    // App.back
    // Global.didBecomine;
    var event = (0, _emmiter.buildEventCenterByName)(eventName);
    if (!onPromises[event.value]) {
      onPromises[event.value] = _rap2.default.call({
        className: event.center,
        methodName: 'addListener',
        param: {
          eventName: event.name,
          timeout: null
        }
      }, function (event) {
        // 设置默认 scope 为 app 级别
        event.value = (event.scope && event.scope.toLowerCase() || 'app') + '.' + event.name;
        eventEmitter.emit(event.value, event.info);
      });
    }

    var promise = onPromises[event.value];
    promise.catch(function (error) {
      delete onPromises[event.value];
    });

    return promise.then(function () {
      eventEmitter.on(event.value, callback);
    });
  },
  off: function off(eventName, callback) {
    var event = (0, _emmiter.buildEventCenterByName)(eventName);
    return eventEmitter.off(event.value, callback).then(function (result) {
      var options = eventEmitter.optionsPool[event.value];
      if (options.length > 0) return result;
      if (!onPromises[event.value]) return result;
      return _rap2.default.call({
        className: event.center,
        methodName: 'removeListener',
        param: {
          eventName: event.name,
          timeout: null
        }
      }).then(function (result) {
        delete onPromises[event.value];
      });
    });

    // return RapBridge.call({
    //   className: event.center,
    //   methodName: 'removeListener',
    //   param: {
    //     eventName: event.name
    //   }
    // });
  },

  emit: function emit(eventName, options) {
    if (_env.isWeb) {
      eventEmitter.emit(eventName, options);
      return new Promise(function (resolve) {
        return resolve();
      });
    }
    var event = (0, _emmiter.buildEventCenterByName)(eventName);
    return _rap2.default.call({
      className: event.center,
      methodName: 'fireEvent',
      param: {
        eventName: event.name,
        info: options,
        timeout: null
      }
    });
  }
};

exports.default = Event;
module.exports = exports['default'];