'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _rap = require('../rap');

var _rap2 = _interopRequireDefault(_rap);

var _isString = require('lodash/isString');

var _isString2 = _interopRequireDefault(_isString);

var _isNumber = require('lodash/isNumber');

var _isNumber2 = _interopRequireDefault(_isNumber);

var _isObject = require('lodash/isObject');

var _isObject2 = _interopRequireDefault(_isObject);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CLASS_NAME = 'navigator';

function formatURL(url) {
  return url;
};

function formatTitle(options) {
  if ((0, _isString2.default)(options)) {
    options = {
      text: options
    };
  } else if ((0, _isObject2.default)(options)) {
    var url = formatURL(options.url);

    if (url) {
      options.url = url;
    }
  } else {
    options = {
      text: ''
    };
  }

  return options;
}

var doOnceInXs = function doOnceInXs(x) {
  var flag = true;

  return function () {
    if (flag) {
      flag = false;
      setTimeout(function () {
        return flag = true;
      }, x);
      return true;
    }
    return false;
  };
};

var hasNotPush = doOnceInXs(3);

var Navigator = {
  push: function push(options) {
    var force = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

    if (!force && !hasNotPush()) {
      return new Promise(function (resolve) {
        resolve({
          msg: 'Do push only in 3 seconds'
        });
      });
    }

    // 如果直接传一个String
    if ((0, _isString2.default)(options)) {
      options = {
        url: options
      };
    }

    var _ref = options || {},
        url = _ref.url,
        title = _ref.title,
        backgroundColor = _ref.backgroundColor,
        _ref$clearTop = _ref.clearTop,
        clearTop = _ref$clearTop === undefined ? false : _ref$clearTop,
        _ref$animated = _ref.animated,
        animated = _ref$animated === undefined ? true : _ref$animated;

    title = formatTitle(title);

    var param = {
      backgroundColor: backgroundColor,
      title: title,
      clearTop: clearTop,
      animated: animated,
      timeout: null
    };

    var resUrl = formatURL(url);

    if (resUrl) {
      param.url = resUrl;
    }

    return _rap2.default.call({
      className: CLASS_NAME,
      methodName: 'push',
      param: param
    });
  },
  pop: function pop(num) {
    var index = 1;
    var animated = true;

    if ((0, _isNumber2.default)(+num)) {
      index = num;
    }

    if ((0, _isObject2.default)(num)) {
      index = num.index;
      animated = num.animated;
    }

    return _rap2.default.call({
      className: CLASS_NAME,
      methodName: 'pop',
      param: {
        index: index,
        animated: animated,
        timeout: null
      }
    });
  },
  popTo: function popTo(param) {
    var index = void 0;

    if (param && param.index) {
      index = param.index;
    } else {
      index = param;
    }

    if (!index) {
      index = 1;
      console.log('index, 为必转参数');
    }

    var animated = param && param.animated;

    return _rap2.default.call({
      className: CLASS_NAME,
      methodName: 'popTo',
      param: {
        index: index,
        animated: animated,
        timeout: null
      }
    });
  },
  setTitle: function setTitle(param) {
    if (!param) {
      param = {
        text: ''
      };
    }
    return _rap2.default.call({
      className: CLASS_NAME,
      methodName: 'setTitle',
      param: _extends({
        timeout: null
      }, formatTitle(param))
    });
  },
  close: function close(param) {
    return _rap2.default.call({
      className: CLASS_NAME,
      methodName: 'close',
      param: _extends({
        timeout: null
      }, param)
    });
  },
  addRightItem: function addRightItem(options, callback) {
    return _rap2.default.call({
      className: CLASS_NAME,
      methodName: 'addRightItem',
      param: _extends({
        timeout: null
      }, options)
    }, callback);
  },
  removeRightItem: function removeRightItem(tagName) {
    return _rap2.default.call({
      className: CLASS_NAME,
      methodName: 'removeRightItem',
      param: {
        timeout: null,
        tag: tagName
      }
    });
  }
};

exports.default = Navigator;
module.exports = exports['default'];