'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _weexModule = require('./weex-module');

var _util = require('../util');

var MODULE_NAME = '@weex-module/rapcaller';

var RBridge = window.RBridge;

/**
 * 调用 native 接口
 * @param {*} options 参数
 * @param {*} callback notify 回调
 */
function call(options, callback) {
  var className = options.className,
      methodName = options.methodName;

  // 支持两种， 这里暂时写param

  var params = options.options || options.param || options.params;

  // 设置默认 timeout
  var timeout = params && params.timeout === undefined ? 10000 : params.timeout;
  var notifyTimeout = params.notifyTimeout || timeout;

  if (!RBridge) {
    RBridge = (0, _weexModule.requireModule)('rapcaller');
  }

  return new Promise(function (resolve, reject) {
    // 在有设置超时时间的情况下，设置超时回调
    var callbackTimeoutDone = false;
    var callbackTimeout = timeout && setTimeout(function () {
      // 标记超时回调已执行
      callbackTimeoutDone = true;
      reject('ERROR. RAP.call timeout. Current timeout is ' + timeout + '.');
    }, timeout);

    // 如果有 notify 回调，这里设置 notify 超时回调
    var notifyCallbackDone = false;
    var notifyCallback = notifyTimeout && setTimeout(function () {
      // 标记超时回调已执行
      notifyCallbackDone = true;
      callback && callback(new Error('RAP.call Notify TIMEOUT ERROR: ' + timeout + '.'));
    }, notifyTimeout);

    RBridge.call && RBridge.call(className, methodName, params, function (success) {
      // 清除正常超时回调
      clearTimeout(callbackTimeout);

      // 如果已经超时，不再进行后续调用
      if (callbackTimeoutDone) return;

      // 成功回调
      resolve((0, _util.parse2json)(success));
    }, function (error) {
      // 清除正常超时回调
      clearTimeout(callbackTimeout);

      if (callbackTimeoutDone) return;

      // 错误回调
      reject((0, _util.parse2json)(error));
    }, function (notify) {
      // 正常回调后，清除notify 超时回调
      clearTimeout(notifyCallback);

      // 如果已经超时，不再进行后续调用
      if (notifyCallbackDone) return;

      // 正常 notify 回调
      callback && callback((0, _util.parse2json)(notify));
    });
  });
};

exports.default = {
  call: call,
  invoke: call,
  requireModule: _weexModule.requireModule
};
module.exports = exports['default'];