'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _util = require('./util');

var _aop = require('./aop');

var _aop2 = _interopRequireDefault(_aop);

var _localstorage = require('./localstorage');

var _localstorage2 = _interopRequireDefault(_localstorage);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var USER_MODULE = '@weex-module/user';
var User = window.require(USER_MODULE);

var extraInfo = false;
var LOCAL_USER_EXTRA_INFO = '__userExtraInfo__';

function setDataToLocal(res, options) {
  var data = {};
  var localKey = LOCAL_USER_EXTRA_INFO + options.nick;
  data[localKey] = JSON.stringify({
    timestramp: Date.now(),
    res: res
  });
  _localstorage2.default.setItem(data);
}

function getDataFromLocal(callback, options) {
  // 默认 30 秒
  var expiresTime = options.expiresTime || 30;
  var localKey = LOCAL_USER_EXTRA_INFO + options.nick;
  _localstorage2.default.getItem([localKey]).then(function (res) {
    var result = res.data[localKey];
    var data = { timestramp: 0 };
    if (result && typeof result === 'string') {
      try {
        data = JSON.parse(result);
      } catch (error) {
        console.error('json parse error', error);
      }
    }

    var nowTimestamp = Date.now();
    var oldTimestamp = data.timestramp;
    var disTimestamp = nowTimestamp - oldTimestamp;

    if (disTimestamp <= 1000 * expiresTime && data.res) {
      console.log('取到 localstorage 缓存数据');
      callback(data.res);
    } else {
      // 未取到本地缓存数据
      console.log('未取到 localstorage 缓存数据');
      callback(false);
    }
  }).catch(function (e) {
    console.log('e', e);
  });
}

function getUserExtraInfo(options) {
  // getUserExtraInfo
  // http://ocn.alibaba-inc.com/isp/apifactory/api/input.htm?name=alibaba.account.basic&namespace=com.alibaba.account&version=1
  return new Promise(function (resolve, reject) {
    if (extraInfo) {
      console.log('复用本地数据');
      return resolve(extraInfo);
    }
    // 先取一下本地的，再去请求线上的
    getDataFromLocal(function (data) {
      if (data) {
        resolve(data);
      } else {
        _aop2.default.request({
          api: 'alibaba.account.basic',
          namespace: 'com.alibaba.account',
          v: '1'
        }).then(function (res) {
          extraInfo = res;
          // 存一下到本地 为了下次请求做缓存
          // __userExtraInfo__: res
          setDataToLocal(res, options);
          resolve(res);
        }, function (error) {
          reject(error);
        });
      }
    }, options);
  });
}
exports.default = {
  getUserInfo: function getUserInfo() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : { extraInfo: false };

    return new Promise(function (resolve, reject) {
      if (User.getUserInfo) {
        var getUserInfo = function getUserInfo() {
          User.getUserInfo(function (info) {
            info = (0, _util.parse2json)(info);
            if (String(info.isLogin) === 'true') {
              info.isLogin = true;
            } else {
              info.isLogin = false;
            }
            if (options.extraInfo) {
              getUserExtraInfo({
                expiresTime: options.expiresTime,
                nick: info.nick
              }).then(function (res) {
                resolve(_extends({}, info, {
                  extraInfo: res
                }));
              }).catch(function (e) {
                resolve(_extends({}, info, {
                  extraInfo: false
                }));
              });
            } else {
              resolve(_extends({}, info, {
                extraInfo: false
              }));
            }
          });
        };

        getUserInfo();
      } else {
        console.warn('请使用阿里巴巴-客户端打开');
        reject(new Error('Please use Alibaba Client'));
      }
    });
  },
  login: function login() {
    return new Promise(function (resolve, reject) {
      if (User.login) {
        User.login(function (ret) {
          ret = (0, _util.parse2json)(ret);
          ret.isLogin = false;

          var status = ret && String(ret.status);

          if (status === 'true' || status === 'success') {
            ret.isLogin = true;
          }

          resolve(ret);
        });
      }
    });
  },
  logout: function logout() {
    return new Promise(function (resolve, reject) {
      if (User.logout) {
        extraInfo = false;
        User.logout(function (result) {
          resolve(result);
        });
      }
    });
  }
};
module.exports = exports['default'];