'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _location = require('../location');

var _location2 = _interopRequireDefault(_location);

var _env = require('../env');

var _weexModule = require('../rap/weex-module');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// import user from './user';

var href = _location2.default.href;

// 是否已经获取 uid 标记位
var hasTryUid = false;

// 默认日志配置
var logItem = {
  pid: 'rap-sdk',
  page: _location2.default.href,
  ua: navigator.userAgent
};

/**
 * 将对象序列化
 * @param {Object} obj k-v 参数对
 */
var toQueryString = function toQueryString(obj) {
  var arr = [];
  for (var key in obj) {
    if (obj.hasOwnProperty(key) && obj[key] != null && obj[key] !== '') {
      arr.push(encodeURIComponent(key) + '=' + encodeURIComponent(obj[key]));
    }
  }
  return arr.join('&');
};

// 将参数数组序列化
var toString = function toString(args) {
  if (args instanceof Array) {
    return args.map(function (arg) {
      return (typeof arg === 'undefined' ? 'undefined' : _typeof(arg)) === 'object' ? JSON.stringify(arg) : arg.toString();
    }).toString();
  }
  return args;
};

/**
 * 发送日志请求
 */
var cache = [];
var postData2Server = function postData2Server(item) {
  // 500 ms 内 cache
  item && cache.push(item);

  // 尝试获取 uid，还未完成的，直接返回
  if (!hasTryUid) return;

  setTimeout(function () {
    while (cache.length > 0) {
      var _item = cache.pop();
      _item.uid = logItem.uid;

      // console.log('logger: ' + JSON.stringify(item));

      if (_env.isWeex) {
        fetch('http://gm.mmstat.com/fsp.1.1?' + toQueryString(_item), { method: 'GET' });
      } else {
        new Image().src = 'http://gm.mmstat.com/fsp.1.1?' + toQueryString(_item);
      }
    }
  }, 500);
};

/**
 * 格式化上传数据
 */
var formatLog = function formatLog(code, msg) {
  var ext = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  return _extends({}, logItem, {
    code: code,
    msg: toString(msg)
  }, ext);
};

/**
 * 日志对象 log, warn, info, error, api, debug
 */
var logger = {
  log: function log() {
    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    postData2Server(formatLog(11, args));
  },
  warn: function warn() {
    for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    postData2Server(formatLog(13, args));
  },
  info: function info() {
    for (var _len3 = arguments.length, args = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
      args[_key3] = arguments[_key3];
    }

    postData2Server(formatLog(12, args));
  },
  error: function error() {
    for (var _len4 = arguments.length, args = Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
      args[_key4] = arguments[_key4];
    }

    var error = args[0];
    postData2Server(formatLog(1, toString(args.slice(1)) || args[0].message, {
      c1: error.stack && error.stack.slice(0, 500),
      c2: error.stack && error.stack.slice(500, 1000),
      c3: error.message
    }));
  },
  api: function api(name, params, time, result) {
    postData2Server(formatLog(14, name, {
      c1: name || '',
      c2: JSON.stringify(params) || '',
      c3: time || '-1',
      c4: JSON.stringify(result) || ''
    }));
  },
  debug: function debug() {
    for (var _len5 = arguments.length, args = Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
      args[_key5] = arguments[_key5];
    }

    /rapDebugMode=1/.test(_location2.default.href) && console.debug(args);
  }
};

// 尝试获取 uid 并做标记
try {
  var USER_MODULE = '@weex-module/user';
  var User = (0, _weexModule.requireModule)(USER_MODULE);

  User.getUserInfo(function (data) {
    try {
      data = JSON.parse(data);
      if (data.info.userId) {
        logItem.uid = data.info.userId;
      }
      hasTryUid = true;
    } catch (e) {
      hasTryUid = true;
    }
    postData2Server();
  });
} catch (e) {
  hasTryUid = true;
  if (_env.isWeex) {
    logger.error(e);
  } else {
    logger.log('web 环境无法获取 userid');
  }
}

exports.default = logger;
module.exports = exports['default'];